<?php   

/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */ 

function optionsframework_option_name() {
	// Change this to use your theme slug
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	return $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'business-growth'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {
	//array of all custom font types.
	$font_types = array( '' => '',
    'ABeeZee' => 'ABeeZee',
    'Abel' => 'Abel',
    'Abril Fatface' => 'Abril Fatface',
    'Aclonica' => 'Aclonica',
    'Acme' => 'Acme',
    'Actor' => 'Actor',
    'Adamina' => 'Adamina',
    'Advent Pro' => 'Advent Pro',
    'Aguafina Script' => 'Aguafina Script',
    'Akronim' => 'Akronim',
    'Aladin' => 'Aladin',
    'Aldrich' => 'Aldrich',
    'Alegreya' => 'Alegreya',
    'Alegreya Sans SC' => 'Alegreya Sans SC',
    'Alegreya SC' => 'Alegreya SC',
    'Alex Brush' => 'Alex Brush',
    'Alef' => 'Alef',
    'Alfa Slab One' => 'Alfa Slab One',
    'Alice' => 'Alice',
    'Alike' => 'Alike',
    'Alike Angular' => 'Alike Angular',
    'Allan' => 'Allan',
    'Allerta' => 'Allerta',
    'Allerta Stencil' => 'Allerta Stencil',
    'Allura' => 'Allura',
    'Almendra' => 'Almendra',
    'Almendra Display' => 'Almendra Display',
    'Almendra SC' => 'Almendra SC',
    'Amiri' => 'Amiri',
    'Amarante' => 'Amarante',
    'Amaranth' => 'Amaranth',
    'Amatic SC' => 'Amatic SC',
    'Amethysta' => 'Amethysta',
    'Amita' => 'Amita',
    'Anaheim' => 'Anaheim',
    'Andada' => 'Andada',
    'Andika' => 'Andika',
    'Annie Use Your Telescope' => 'Annie Use Your Telescope',
    'Anonymous Pro' => 'Anonymous Pro',
    'Antic' => 'Antic',
    'Antic Didone' => 'Antic Didone',
    'Antic Slab' => 'Antic Slab',
    'Anton' => 'Anton',
    'Angkor' => 'Angkor',
    'Arapey' => 'Arapey',
    'Arbutus' => 'Arbutus',
    'Arbutus Slab' => 'Arbutus Slab',
    'Architects Daughter' => 'Architects Daughter',
    'Archivo White' => 'Archivo White',
    'Archivo Narrow' => 'Archivo Narrow',
    'Arial' => 'Arial',
    'Arimo' => 'Arimo',
    'Arya' => 'Arya',
    'Arizonia' => 'Arizonia',
    'Armata' => 'Armata',
    'Artifika' => 'Artifika',
    'Arvo' => 'Arvo',
    'Asar' => 'Asar',
    'Asap' => 'Asap',
    'Asset' => 'Asset',
    'Astloch' => 'Astloch',
    'Asul' => 'Asul',
    'Atomic Age' => 'Atomic Age',
    'Aubrey' => 'Aubrey',
    'Audiowide' => 'Audiowide',
    'Autour One' => 'Autour One',
    'Average' => 'Average',
    'Average Sans' => 'Average Sans',
    'Averia Gruesa Libre' => 'Averia Gruesa Libre',
    'Averia Libre' => 'Averia Libre',
    'Averia Sans Libre' => 'Averia Sans Libre',
    'Averia Serif Libre' => 'Averia Serif Libre',
    'Battambang' => 'Battambang',
    'Bad Script' => 'Bad Script',
    'Bayon' => 'Bayon',
    'Balthazar' => 'Balthazar',
    'Bangers' => 'Bangers',
    'Basic' => 'Basic',
    'Baumans' => 'Baumans',
    'Belgrano' => 'Belgrano',
    'Belleza' => 'Belleza',
    'BenchNine' => 'BenchNine',
    'Bentham' => 'Bentham',
    'Berkshire Swash' => 'Berkshire Swash',
    'Bevan' => 'Bevan',
    'Bigelow Rules' => 'Bigelow Rules',
    'Bigshot One' => 'Bigshot One',
    'Bilbo' => 'Bilbo',
    'Bilbo Swash Caps' => 'Bilbo Swash Caps',
    'Biryani' => 'Biryani',
    'Bitter' => 'Bitter',
    'White Ops One' => 'White Ops One',
    'Bokor' => 'Bokor',
    'Bonbon' => 'Bonbon',
    'Boogaloo' => 'Boogaloo',
    'Bowlby One' => 'Bowlby One',
    'Bowlby One SC' => 'Bowlby One SC',
    'Brawler' => 'Brawler',
    'Bree Serif' => 'Bree Serif',
    'Bubblegum Sans' => 'Bubblegum Sans',
    'Bubbler One' => 'Bubbler One',
    'Buda' => 'Buda',
    'Buenard' => 'Buenard',
    'Butcherman' => 'Butcherman',
    'Butcherman Caps' => 'Butcherman Caps',
    'Butterfly Kids' => 'Butterfly Kids',
    'Cabin' => 'Cabin',
    'Cabin Condensed' => 'Cabin Condensed',
    'Cabin Sketch' => 'Cabin Sketch',
    'Cabin' => 'Cabin',
    'Caesar Dressing' => 'Caesar Dressing',
    'Cagliostro' => 'Cagliostro',
    'Calligraffitti' => 'Calligraffitti',
    'Cambay' => 'Cambay',
    'Cambo' => 'Cambo',
    'Candal' => 'Candal',
    'Cantarell' => 'Cantarell',
    'Cantata One' => 'Cantata One',
    'Cantora One' => 'Cantora One',
    'Capriola' => 'Capriola',
    'Cardo' => 'Cardo',
    'Carme' => 'Carme',
    'Carrois Gothic' => 'Carrois Gothic',
    'Carrois Gothic SC' => 'Carrois Gothic SC',
    'Carter One' => 'Carter One',
    'Caveat' => 'Caveat',
    'Caveat Brush' => 'Caveat Brush',
    'Catamaran' => 'Catamaran',
    'Caudex' => 'Caudex',
    'Cedarville Cursive' => 'Cedarville Cursive',
    'Ceviche One' => 'Ceviche One',
    'Changa One' => 'Changa One',
    'Chango' => 'Chango',
    'Chau Philomene One' => 'Chau Philomene One',
    'Chenla' => 'Chenla',
    'Chela One' => 'Chela One',
    'Chelsea Market' => 'Chelsea Market',
    'Cherry Cream Soda' => 'Cherry Cream Soda',
    'Cherry Swash' => 'Cherry Swash',
    'Chewy' => 'Chewy',
    'Chicle' => 'Chicle',
    'Chivo' => 'Chivo',
    'Chonburi' => 'Chonburi',
    'Cinzel' => 'Cinzel',
    'Cinzel Decorative' => 'Cinzel Decorative',
    'Clicker Script' => 'Clicker Script',
    'Coda' => 'Coda',
    'Codystar' => 'Codystar',
    'Combo' => 'Combo',
    'Comfortaa' => 'Comfortaa',
    'Coming Soon' => 'Coming Soon',
    'Condiment' => 'Condiment',
    'Content' => 'Content',
    'Contrail One' => 'Contrail One',
    'Convergence' => 'Convergence',
    'Cookie' => 'Cookie',
    'Comic Sans MS' => 'Comic Sans MS',
    'Copse' => 'Copse',
    'Corben' => 'Corben',
    'Courgette' => 'Courgette',
    'Cousine' => 'Cousine',
    'Coustard' => 'Coustard',
    'Covered By Your Grace' => 'Covered By Your Grace',
    'Crafty Girls' => 'Crafty Girls',
    'Creepster' => 'Creepster',
    'Creepster Caps' => 'Creepster Caps',
    'Crete Round' => 'Crete Round',
    'Crimson' => 'Crimson',
    'Croissant One' => 'Croissant One',
    'Crushed' => 'Crushed',
    'Cuprum' => 'Cuprum',
    'Cutive' => 'Cutive',
    'Cutive Mono' => 'Cutive Mono',
    'Damion' => 'Damion',
    'Dangrek' => 'Dangrek',
    'Dancing Script' => 'Dancing Script',
    'Dawning of a New Day' => 'Dawning of a New Day',
    'Days One' => 'Days One',
    'Dekko' => 'Dekko',
    'Delius' => 'Delius',
    'Delius Swash Caps' => 'Delius Swash Caps',
    'Delius Unicase' => 'Delius Unicase',
    'Della Respira' => 'Della Respira',
    'Denk One' => 'Denk One',
    'Devonshire' => 'Devonshire',
    'Dhurjati' => 'Dhurjati',
    'Didact Gothic' => 'Didact Gothic',
    'Diplomata' => 'Diplomata',
    'Diplomata SC' => 'Diplomata SC',
    'Domine' => 'Domine',
    'Donegal One' => 'Donegal One',
    'Doppio One' => 'Doppio One',
    'Dorsa' => 'Dorsa',
    'Dosis' => 'Dosis',
    'Dr Sugiyama' => 'Dr Sugiyama',
    'Droid Sans' => 'Droid Sans',
    'Droid Sans Mono' => 'Droid Sans Mono',
    'Droid Serif' => 'Droid Serif',
    'Duru Sans' => 'Duru Sans',
    'Dynalight' => 'Dynalight',
    'EB Garamond' => 'EB Garamond',
    'Eczar' => 'Eczar',
    'Eagle Lake' => 'Eagle Lake',
    'Eater' => 'Eater',
    'Eater Caps' => 'Eater Caps',
    'Economica' => 'Economica',
    'Ek Mukta' => 'Ek Mukta',
    'Electrolize' => 'Electrolize',
    'Elsie' => 'Elsie',
    'Elsie Swash Caps' => 'Elsie Swash Caps',
    'Emblema One' => 'Emblema One',
    'Emilys Candy' => 'Emilys Candy',
    'Engagement' => 'Engagement',
    'Englebert' => 'Englebert',
    'Enriqueta' => 'Enriqueta',
    'Erica One' => 'Erica One',
    'Esteban' => 'Esteban',
    'Euphoria Script' => 'Euphoria Script',
    'Ewert' => 'Ewert',
    'Exo' => 'Exo',
    'Exo 2' => 'Exo 2',
    'Expletus Sans' => 'Expletus Sans',
    'Fanwood Text' => 'Fanwood Text',
    'Fascinate' => 'Fascinate',
    'Fascinate Inline' => 'Fascinate Inline',
    'Fasthand' => 'Fasthand',
    'Faster One' => 'Faster One',
    'Federant' => 'Federant',
    'Federo' => 'Federo',
    'Felipa' => 'Felipa',
    'Fenix' => 'Fenix',
    'Finger Paint' => 'Finger Paint',
    'Fira Mono' => 'Fira Mono',
    'Fira Sans' => 'Fira Sans',
    'Fjalla One' => 'Fjalla One',
    'Fjord One' => 'Fjord One',
    'Flamenco' => 'Flamenco',
    'Flavors' => 'Flavors',
    'Fondamento' => 'Fondamento',
    'Fontdiner Swanky' => 'Fontdiner Swanky',
    'Forum' => 'Forum',
    'Francois One' => 'Francois One',
    'FreeSans' => 'FreeSans',


    'Freckle Face' => 'Freckle Face',
    'Fredericka the Great' => 'Fredericka the Great',
    'Fredoka One' => 'Fredoka One',
    'Fresca' => 'Fresca',
    'Freehand' => 'Freehand',
    'Frijole' => 'Frijole',
    'Fruktur' => 'Fruktur',
    'Fugaz One' => 'Fugaz One',
    'Gafata' => 'Gafata',
    'Galdeano' => 'Galdeano',
    'Galindo' => 'Galindo',
    'Gentium Basic' => 'Gentium Basic',
    'Gentium Book Basic' => 'Gentium Book Basic',
    'Geo' => 'Geo',
    'Georgia' => 'Georgia',
    'Geostar' => 'Geostar',
    'Geostar Fill' => 'Geostar Fill',
    'Germania One' => 'Germania One',
    'Gilda Display' => 'Gilda Display',
    'Give You Glory' => 'Give You Glory',
    'Glass Antiqua' => 'Glass Antiqua',
    'Glegoo' => 'Glegoo',
    'Gloria Hallelujah' => 'Gloria Hallelujah',
    'Goblin One' => 'Goblin One',
    'Gochi Hand' => 'Gochi Hand',
    'Gorditas' => 'Gorditas',
    'Gurajada' => 'Gurajada',
    'Goudy Bookletter 1911' => 'Goudy Bookletter 1911',
    'Graduate' => 'Graduate',
    'Grand Hotel' => 'Grand Hotel',
    'Gravitas One' => 'Gravitas One',
    'Great Vibes' => 'Great Vibes',
    'Griffy' => 'Griffy',
    'Gruppo' => 'Gruppo',
    'Gudea' => 'Gudea',
    'Gidugu' => 'Gidugu',
    'GFS Didot' => 'GFS Didot',
    'GFS Neohellenic' => 'GFS Neohellenic',
    'Habibi' => 'Habibi',
    'Hammersmith One' => 'Hammersmith One',
    'Halant' => 'Halant',
    'Hanalei' => 'Hanalei',
    'Hanalei Fill' => 'Hanalei Fill',
    'Handlee' => 'Handlee',
    'Hanuman' => 'Hanuman',
    'Happy Monkey' => 'Happy Monkey',
    'Headland One' => 'Headland One',
    'Henny Penny' => 'Henny Penny',
    'Herr Von Muellerhoff' => 'Herr Von Muellerhoff',
    'Hind' => 'Hind',
    'Hind Siliguri' => 'Hind Siliguri',
    'Hind Vadodara' => 'Hind Vadodara',
    'Holtwood One SC' => 'Holtwood One SC',
    'Homemade Apple' => 'Homemade Apple',
    'Homenaje' => 'Homenaje',
    'IM Fell' => 'IM Fell',
    'Itim' => 'Itim',
    'Iceberg' => 'Iceberg',
    'Iceland' => 'Iceland',
    'Imprima' => 'Imprima',
    'Inconsolata' => 'Inconsolata',
    'Inder' => 'Inder',
    'Indie Flower' => 'Indie Flower',
    'Inknut Antiqua' => 'Inknut Antiqua',
    'Inika' => 'Inika',
    'Irish Growler' => 'Irish Growler',
    'Istok Web' => 'Istok Web',
    'Italiana' => 'Italiana',
    'Italianno' => 'Italianno',
    'Jacques Francois' => 'Jacques Francois',
    'Jacques Francois Shadow' => 'Jacques Francois Shadow',
    'Jim Nightshade' => 'Jim Nightshade',
    'Jockey One' => 'Jockey One',
    'Jaldi' => 'Jaldi',
    'Jolly Lodger' => 'Jolly Lodger',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Slab' => 'Josefin Slab',
    'Joti One' => 'Joti One',
    'Judson' => 'Judson',
    'Julee' => 'Julee',
    'Julius Sans One' => 'Julius Sans One',
    'Junge' => 'Junge',
    'Jura' => 'Jura',
    'Just Another Hand' => 'Just Another Hand',
    'Just Me Again Down Here' => 'Just Me Again Down Here',
    'Kadwa' => 'Kadwa',
    'Kdam Thmor' => 'Kdam Thmor',
    'Kalam' => 'Kalam', 
    'Kameron' => 'Kameron',
    'Kantumruy' => 'Kantumruy',
    'Karma' => 'Karma',
    'Karla' => 'Karla',
    'Kaushan Script' => 'Kaushan Script',
    'Kavoon' => 'Kavoon',
    'Keania One' => 'Keania One',
    'Kelly Slab' => 'Kelly Slab',
    'Kenia' => 'Kenia',
    'Khand' => 'Khand',
    'Khmer' => 'Khmer',
    'Khula' => 'Khula',
    'Kite One' => 'Kite One',
    'Knewave' => 'Knewave',
    'Kotta One' => 'Kotta One',
    'Kranky' => 'Kranky',
    'Kreon' => 'Kreon',
    'Kristi' => 'Kristi',
    'Koulen' => 'Koulen',
    'Krona One' => 'Krona One',
    'Kurale' => 'Kurale',
    'Lakki Reddy' => 'Lakki Reddy',
    'La Belle Aurore' => 'La Belle Aurore',
    'Lancelot' => 'Lancelot',
    'Laila' => 'Laila',
    'Lato' => 'Lato',
    'Lateef' => 'Lateef',
    'League Script' => 'League Script',
    'Leckerli One' => 'Leckerli One',
    'Ledger' => 'Ledger',
    'Lekton' => 'Lekton',
    'Lemon' => 'Lemon',

    'Libre Baskerville' => 'Libre Baskerville',
    'Life Savers' => 'Life Savers',
    'Lilita One' => 'Lilita One',
    'Limelight' => 'Limelight',
    'Linden Hill' => 'Linden Hill',
    'Lobster' => 'Lobster',
    'Lobster Two' => 'Lobster Two',
    'Londrina Outline' => 'Londrina Outline',
    'Londrina Shadow' => 'Londrina Shadow',
    'Londrina Sketch' => 'Londrina Sketch',
    'Londrina Solid' => 'Londrina Solid',
    'Lora' => 'Lora',
    'Love Ya Like A Sister' => 'Love Ya Like A Sister',
    'Loved by the King' => 'Loved by the King',
    'Lovers Quarrel' => 'Lovers Quarrel',
    'Lucida Sans Unicode' => 'Lucida Sans Unicode',
    'Luckiest Guy' => 'Luckiest Guy',
    'Lusitana' => 'Lusitana',
    'Lustria' => 'Lustria',
    'Macondo' => 'Macondo',
    'Macondo Swash Caps' => 'Macondo Swash Caps',
    'Magra' => 'Magra',
    'Maiden Orange' => 'Maiden Orange',
    'Mallanna' => 'Mallanna',
    'Mandali' => 'Mandali',
    'Mako' => 'Mako',
    'Marcellus' => 'Marcellus',
    'Marcellus SC' => 'Marcellus SC',
    'Marck Script' => 'Marck Script',
    'Margarine' => 'Margarine',
    'Marko One' => 'Marko One',
    'Marmelad' => 'Marmelad',
    'Marvel' => 'Marvel',
    'Martel' => 'Martel',
    'Martel Sans' => 'Martel Sans',
    'Mate' => 'Mate',
    'Mate SC' => 'Mate SC',
    'Maven Pro' => 'Maven Pro',
    'McLaren' => 'McLaren',
    'Meddon' => 'Meddon',
    'MedievalSharp' => 'MedievalSharp',
    'Medula One' => 'Medula One',
    'Megrim' => 'Megrim',
    'Meie Script' => 'Meie Script',
    'Merienda' => 'Merienda',
    'Merienda One' => 'Merienda One',
    'Merriweather' => 'Merriweather',
    'Metal' => 'Metal',
    'Metal Mania' => 'Metal Mania',
    'Metamorphous' => 'Metamorphous',
    'Metrophobic' => 'Metrophobic',
    'Michroma' => 'Michroma',
    'Milonga' => 'Milonga',
    'Miltonian' => 'Miltonian',
    'Miltonian Tattoo' => 'Miltonian Tattoo',
    'Miniver' => 'Miniver',
    'Miss Fajardose' => 'Miss Fajardose',
    'Miss Saint Delafield' => 'Miss Saint Delafield',
    'Modak' => 'Modak',
    'Modern Antiqua' => 'Modern Antiqua',
    'Molengo' => 'Molengo',
    'Molle' => 'Molle',
    'Moulpali' => 'Moulpali',
    'Monda' => 'Monda',
    'Monofett' => 'Monofett',
    'Monoton' => 'Monoton',
    'Monsieur La Doulaise' => 'Monsieur La Doulaise',
    'Montaga' => 'Montaga',
    'Montez' => 'Montez',
    'Montserrat' => 'Montserrat',
    'Montserrat Alternates' => 'Montserrat Alternates',
    'Montserrat Subrayada' => 'Montserrat Subrayada',
    'Mountains of Christmas' => 'Mountains of Christmas',
    'Mouse Memoirs' => 'Mouse Memoirs',
    'Moul' => 'Moul',
    'Mr Bedford' => 'Mr Bedford',
    'Mr Bedfort' => 'Mr Bedfort',
    'Mr Dafoe' => 'Mr Dafoe',
    'Mr De Haviland' => 'Mr De Haviland',
    'Mrs Saint Delafield' => 'Mrs Saint Delafield',
    'Mrs Sheppards' => 'Mrs Sheppards',
    'Muli' => 'Muli',
    'Mystery Quest' => 'Mystery Quest',
    'Neucha' => 'Neucha',
    'Neuton' => 'Neuton',
    'New Rocker' => 'New Rocker',
    'News Cycle' => 'News Cycle',
    'Niconne' => 'Niconne',
    'Nixie One' => 'Nixie One',
    'Nobile' => 'Nobile',
    'Nokora' => 'Nokora',
    'Norican' => 'Norican',
    'Nosifer' => 'Nosifer',
    'Nosifer Caps' => 'Nosifer Caps',
    'Nova Mono' => 'Nova Mono',
    'Noticia Text' => 'Noticia Text',
    'Noto Sans' => 'Noto Sans',
    'Noto Serif' => 'Noto Serif',
    'Nova Round' => 'Nova Round',
    'Numans' => 'Numans',
    'Nunito' => 'Nunito',
    'NTR' => 'NTR',
    'Offside' => 'Offside',
    'Oldenburg' => 'Oldenburg',
    'Oleo Script' => 'Oleo Script',
    'Oleo Script Swash Caps' => 'Oleo Script Swash Caps',
    'Open Sans' => 'Open Sans',
    'Open Sans Condensed' => 'Open Sans Condensed',
    'Oranienbaum' => 'Oranienbaum',
    'Orbitron' => 'Orbitron',
    'Odor Mean Chey' => 'Odor Mean Chey',
    'Oregano' => 'Oregano',
    'Orienta' => 'Orienta',
    'Original Surfer' => 'Original Surfer',
    'Oswald' => 'Oswald',
    'Over the Rainbow' => 'Over the Rainbow',
    'Overlock' => 'Overlock',
    'Overlock SC' => 'Overlock SC',
    'Ovo' => 'Ovo',
    'Oxygen' => 'Oxygen',
    'Oxygen Mono' => 'Oxygen Mono',
    'Palanquin Dark' => 'Palanquin Dark',
    'Peddana' => 'Peddana',
    'Poppins' => 'Poppins',
    'PT Mono' => 'PT Mono',
    'PT Sans' => 'PT Sans',
    'PT Sans Caption' => 'PT Sans Caption',
    'PT Sans Narrow' => 'PT Sans Narrow',
    'PT Serif' => 'PT Serif',
    'PT Serif Caption' => 'PT Serif Caption',
    'Pacifico' => 'Pacifico',
    'Paprika' => 'Paprika',
    'Parisienne' => 'Parisienne',
    'Passero One' => 'Passero One',
    'Passion One' => 'Passion One',
    'Patrick Hand' => 'Patrick Hand',
    'Patrick Hand SC' => 'Patrick Hand SC',
    'Patua One' => 'Patua One',
    'Paytone One' => 'Paytone One',
    'Peralta' => 'Peralta',
    'Permanent Marker' => 'Permanent Marker',
    'Petit Formal Script' => 'Petit Formal Script',
    'Petrona' => 'Petrona',
    'Philosopher' => 'Philosopher',
    'Piedra' => 'Piedra',
    'Pinyon Script' => 'Pinyon Script',
    'Pirata One' => 'Pirata One',
    'Plaster' => 'Plaster',
    'Palatino Linotype' => 'Palatino Linotype',
    'Play' => 'Play',
    'Playball' => 'Playball',
    'Playfair Display' => 'Playfair Display',
    'Playfair Display SC' => 'Playfair Display SC',
    'Podkova' => 'Podkova',
    'Poiret One' => 'Poiret One',
    'Poller One' => 'Poller One',
    'Poly' => 'Poly',
    'Pompiere' => 'Pompiere',
    'Pontano Sans' => 'Pontano Sans',
    'Port Lligat Sans' => 'Port Lligat Sans',
    'Port Lligat Slab' => 'Port Lligat Slab',
    'Prata' => 'Prata',
    'Pragati Narrow' => 'Pragati Narrow',
    'Preahvihear' => 'Preahvihear',
    'Press Start 2P' => 'Press Start 2P',
    'Princess Sofia' => 'Princess Sofia',
    'Prociono' => 'Prociono',
    'Prosto One' => 'Prosto One',
    'Puritan' => 'Puritan',
    'Purple Purse' => 'Purple Purse',
    'Quando' => 'Quando',
    'Quantico' => 'Quantico',
    'Quattrocento' => 'Quattrocento',
    'Quattrocento Sans' => 'Quattrocento Sans',
    'Questrial' => 'Questrial',
    'Quicksand' => 'Quicksand',
    'Quintessential' => 'Quintessential',
    'Qwigley' => 'Qwigley',
    'Racing Sans One' => 'Racing Sans One',
    'Radley' => 'Radley',
    'Rajdhani' => 'Rajdhani',
    'Raleway Dots' => 'Raleway Dots',
    'Raleway' => 'Raleway',
    'Rambla' => 'Rambla',
    'Ramabhadra' => 'Ramabhadra',
    'Ramaraja' => 'Ramaraja',
    'Rammetto One' => 'Rammetto One',
    'Ranchers' => 'Ranchers',
    'Rancho' => 'Rancho',
    'Ranga' => 'Ranga',
    'Ravi Prakash' => 'Ravi Prakash',
    'Rationale' => 'Rationale',
    'Redressed' => 'Redressed',
    'Reenie Beanie' => 'Reenie Beanie',
    'Revalia' => 'Revalia',
    'Rhodium Libre' => 'Rhodium Libre',
    'Ribeye' => 'Ribeye',
    'Ribeye Marrow' => 'Ribeye Marrow',
    'Righteous' => 'Righteous',
    'Risque' => 'Risque',
    'Roboto' => 'Roboto',
    'Roboto Condensed' => 'Roboto Condensed',
    'Roboto Mono' => 'Roboto Mono',
    'Roboto Slab' => 'Roboto Slab',
    'Rochester' => 'Rochester',
    'Rock Salt' => 'Rock Salt',
    'Rokkitt' => 'Rokkitt',
    'Romanesco' => 'Romanesco',
    'Ropa Sans' => 'Ropa Sans',
    'Rosario' => 'Rosario',
    'Rosarivo' => 'Rosarivo',
    'Rouge Script' => 'Rouge Script',
    'Rozha One' => 'Rozha One',
    'Rubik' => 'Rubik',
    'Rubik One' => 'Rubik One',
    'Rubik Mono One' => 'Rubik Mono One',
    'Ruda' => 'Ruda',
    'Rufina' => 'Rufina',
    'Ruge Boogie' => 'Ruge Boogie',
    'Ruluko' => 'Ruluko',
    'Rum Raisin' => 'Rum Raisin',
    'Ruslan Display' => 'Ruslan Display',
    'Russo One' => 'Russo One',
    'Ruthie' => 'Ruthie',
    'Rye' => 'Rye',
    'Sacramento' => 'Sacramento',
    'Sail' => 'Sail',
    'Salsa' => 'Salsa',
    'Sanchez' => 'Sanchez',
    'Sancreek' => 'Sancreek',
    'Sahitya' => 'Sahitya',
    'Sansita One' => 'Sansita One',
    'Sarpanch' => 'Sarpanch',
    'Sarina' => 'Sarina',
    'Satisfy' => 'Satisfy',
    'Scada' => 'Scada',
    'Scheherazade' => 'Scheherazade',
    'Schoolbell' => 'Schoolbell',
    'Seaweed Script' => 'Seaweed Script',
    'Sarala' => 'Sarala',
    'Sevillana' => 'Sevillana',
    'Seymour One' => 'Seymour One',
    'Shadows Into Light' => 'Shadows Into Light',
    'Shadows Into Light Two' => 'Shadows Into Light Two',
    'Shanti' => 'Shanti',
    'Share' => 'Share',
    'Share Tech' => 'Share Tech',
    'Share Tech Mono' => 'Share Tech Mono',
    'Shojumaru' => 'Shojumaru',
    'Short Stack' => 'Short Stack',
    'Sigmar One' => 'Sigmar One',
    'Suranna' => 'Suranna',
    'Suravaram' => 'Suravaram',
    'Suwannaphum' => 'Suwannaphum',
    'Signika' => 'Signika',
    'Signika Negative' => 'Signika Negative',
    'Simonetta' => 'Simonetta',
    'Siemreap' => 'Siemreap',
    'Sirin Stencil' => 'Sirin Stencil',
    'Six Caps' => 'Six Caps',
    'Skranji' => 'Skranji',
    'Slackey' => 'Slackey',
    'Smokum' => 'Smokum',
    'Smythe' => 'Smythe',
    'Sniglet' => 'Sniglet',
    'Snippet' => 'Snippet',
    'Snowburst One' => 'Snowburst One',
    'Sofadi One' => 'Sofadi One',
    'Sofia' => 'Sofia',
    'Sonsie One' => 'Sonsie One',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Source Code Pro' => 'Source Code Pro',
    'Source Sans Pro' => 'Source Sans Pro',
    'Special I am one' => 'Special I am one',
    'Spicy Rice' => 'Spicy Rice',
    'Spinnaker' => 'Spinnaker',
    'Spirax' => 'Spirax',
    'Squada One' => 'Squada One',
    'Sree Krushnadevaraya' => 'Sree Krushnadevaraya',
    'Stalemate' => 'Stalemate',
    'Stalinist One' => 'Stalinist One',
    'Stardos Stencil' => 'Stardos Stencil',
    'Stint Ultra Condensed' => 'Stint Ultra Condensed',
    'Stint Ultra Expanded' => 'Stint Ultra Expanded',
    'Stoke' => 'Stoke',
    'Stoke' => 'Stoke',
    'Strait' => 'Strait',
    'Sura' => 'Sura',
    'Sumana' => 'Sumana',
    'Sue Ellen Francisco' => 'Sue Ellen Francisco',
    'Sunshiney' => 'Sunshiney',
    'Supermercado One' => 'Supermercado One',
    'Swanky and Moo Moo' => 'Swanky and Moo Moo',
    'Syncopate' => 'Syncopate',
    'Symbol' => 'Symbol',
    'Timmana' => 'Timmana',
    'Taprom' => 'Taprom',
    'Tangerine' => 'Tangerine',
    'Tahoma' => 'Tahoma',
    'Teko' => 'Teko',
    'Telex' => 'Telex',
    'Tenali Ramakrishna' => 'Tenali Ramakrishna',
    'Tenor Sans' => 'Tenor Sans',
    'Terminal Dosis' => 'Terminal Dosis',
    'Terminal Dosis Light' => 'Terminal Dosis Light',
    'Text Me One' => 'Text Me One',
    'The Girl Next Door' => 'The Girl Next Door',
    'Tienne' => 'Tienne',
    'Tillana' => 'Tillana',
    'Tinos' => 'Tinos',
    'Titan One' => 'Titan One',
    'Titillium Web' => 'Titillium Web',
    'Trade Winds' => 'Trade Winds',
    'Trebuchet MS' => 'Trebuchet MS',
    'Trocchi' => 'Trocchi',
    'Trochut' => 'Trochut',
    'Trykker' => 'Trykker',
    'Tulpen One' => 'Tulpen One',
    'Ubuntu' => 'Ubuntu',
    'Ubuntu Condensed' => 'Ubuntu Condensed',
    'Ubuntu Mono' => 'Ubuntu Mono',
    'Ultra' => 'Ultra',
    'Uncial Antiqua' => 'Uncial Antiqua',
    'Underdog' => 'Underdog',
    'Unica One' => 'Unica One',
    'UnifrakturCook' => 'UnifrakturCook',
    'UnifrakturMaguntia' => 'UnifrakturMaguntia',
    'Unkempt' => 'Unkempt',
    'Unlock' => 'Unlock',
    'Unna' => 'Unna',
    'VT323' => 'VT323',
    'Vampiro One' => 'Vampiro One',
    'Varela' => 'Varela',
    'Varela Round' => 'Varela Round',
    'Vast Shadow' => 'Vast Shadow',
    'Vesper Libre' => 'Vesper Libre',
    'Verdana' => 'Verdana',
    'Vibur' => 'Vibur',
    'Vidaloka' => 'Vidaloka',
    'Viga' => 'Viga',
    'Voces' => 'Voces',
    'Volkhov' => 'Volkhov',
    'Vollkorn' => 'Vollkorn',
    'Voltaire' => 'Voltaire',
    'Waiting for the Sunrise' => 'Waiting for the Sunrise',
    'Wallpoet' => 'Wallpoet',
    'Walter Turncoat' => 'Walter Turncoat',
    'Warnes' => 'Warnes',
    'Wellfleet' => 'Wellfleet',
    'Wendy One' => 'Wendy One',
    'Wire One' => 'Wire One',
    'Yanone Kaffeesatz' => 'Yanone Kaffeesatz',
    'Yantramanav' => 'Yantramanav',
    'Yellowtail' => 'Yellowtail',
    'Yeseva One' => 'Yeseva One',
    'Yesteryear' => 'Yesteryear',
    'Zeyada' => 'Zeyada'
	);

	//array of all font sizes.
	$font_sizes = array( 
		'10px' => '10px',
		'11px' => '11px',
	);
	for($n=12;$n<=200;$n+=1){
		$font_sizes[$n.'px'] = $n.'px';
	}
	
	// Pull all the pages into an array
	 $options_pages = array();
	 $options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	 $options_pages[''] = 'Select a page:';
	 foreach ($options_pages_obj as $page) {
	  $options_pages[$page->ID] = $page->post_title;
	 }

	// array of section content.
	$section_text = array(	
		1 => array(
			'section_title'	=> '',
			'menutitle'		=> 'aboutsection',
			'bgcolor' 		=> '#FCFCFC',
			'bgimage'		=> '',
			'class'			=> 'about-wrap',
			'content'		=> '[column_content type="one_half"]<h2>100% Responsive Design</h2>[underline]<p> Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus consectetuer adipiscing elit.</p>

<p>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.Integer tincidunt. Cras dapibus. Vivamus elementum semper nisi.Aenean vulputate eleifend tellus consectetuer adipiscing Cras dapibus. Vivamus elementum semper nisi.</p>
<p> Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus consectetuer adipiscing elit.</p><a class="rdmore" href="#">Read More &raquo;</a>[/column_content]

[column_content type="one_half_last"]<img src="'.get_template_directory_uri().'/images/iphone.png" alt="" />[/column_content]'
		),
		
		2 => array(
			'section_title'	=> 'Our Theme Featured',
			'menutitle'		=> 'ThemeFeaturd',
			'bgcolor' 		=> '#FCFCFC',
			'bgimage'		=> '',
			'class'			=> 'feature-wrap',
			'content'		=> '[underline marginbottom="50"][column_content type="frdbox"]<i class="fa fa-tablet"></i>
			<h4>100% Responsive</h4><p>Lorem ipsum dolor sit amet, consectetur adipiscinr dolor sit amet.</p>[/column_content][column_content type="frdbox"]<i class="fa fa-code"></i>
			<h4>Custom Shortcodes</h4><p>Lorem ipsum dolordolor sit amet sit amet, consectetur adipiscinr</p>[/column_content][column_content type="frdbox"]<i class="fa fa-support"></i>
			<h4>Customer Support</h4><p>Lorem dolor sit ametipsum  dolor sit amet, consectetur adipiscinr</p>[/column_content][column_content type="frdbox last"]<i class="fa fa-file-word-o"></i>
			<h4>Well Documented</h4><p>Lorem ipsum dolor sit amet,  ullamcorper tellus Cras.</p>[/column_content][column_content type="frdbox"]<i class="fa fa-html5"></i>
			<h4>HTML5 & CSS3</h4><p>Lorem ipsum dolor sit amet, dolor sit amet consectetur adipiscinr sed.</p>[/column_content][column_content type="frdbox"]<i class="fa fa-gears"></i>
			<h4>Unlimited Colors</h4><p>Lorem ipsum dolor sit amet, dolor sit amet consectetur adipiscinr</p>[/column_content][column_content type="frdbox"]<i class="fa fa-mail-reply"></i>
			<h4>User Friendly</h4><p>Lorem ipsum dolor sit  dolor sit amet amet, consectetur adipiscinr</p>[/column_content][column_content type="frdbox last"]<i class="fa fa-cloud-download"></i>
			<h4>SEO Friendly</h4><p>Lorem ipsum dolor sit amet dolor sit amet,  ullamcorper tellus Cras.</p>[/column_content]'
		),	
		
		3 => array(
			'section_title'	=> 'Recents Posts',
			'menutitle'		=> 'latestposts',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'posts-wrap',
			'content'		=> '[underline marginbottom="50"][recent-posts show="4"]'
		),
		
		4 => array(
			'section_title'	=> 'Clients Testimonials',
			'menutitle'		=> 'testimonialsarea',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/tmbg.jpg',
			'class'			=> 'testimonials-wrap',
			'content'		=> '[underline marginbottom="50"][testimonials]',
		
		),
		
		5 => array(
			'section_title'	=> 'Our Creative Team',
			'menutitle'		=> 'creativeteam',
			'bgcolor' 		=> '#FCFCFC',
			'bgimage'		=> '',
			'class'			=> 'team-wrap',
			'content'		=> '[underline marginbottom="50"][ourteam show="4"]'
		),
		
		6 => array(
			'section_title'	=> 'Photo Gallery',
			'menutitle'		=> 'ourgallery',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'gallery-wrap',
			'content'		=> '[underline marginbottom="50"][photogallery filter="true" show="8"]'
		),
		
		7 => array(
			'section_title'	=> 'Our Clients',
			'menutitle'		=> 'ourclients',
			'bgcolor' 		=> '#FCFCFC',
			'bgimage'		=> '',
			'bgvideo'		=> '',
			'class'			=> 'client-wrap',
			'content'		=> '[underline marginbottom="50"][client_lists][client image="'.get_template_directory_uri().'/images/client-logo1.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo2.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo3.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo4.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo5.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo6.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo7.jpg" link="#"][client image="'.get_template_directory_uri().'/images/client-logo8.jpg" link="#"][/client_lists]',
		),	

	);

	$options = array();

	//Basic Settings
	$options[] = array(
		'name' => __('Basic Settings', 'business-growth'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo', 'business-growth'),
		'desc' => __('Upload your main logo here', 'business-growth'),
		'id' => 'logo',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(		
		'desc' => __('custom logo height', 'business-growth'),
		'id' => 'logoheight',
		'std' => '35',
		'type' => 'text');
		
	$options[] = array(	
		'name' => __('Site title & Description', 'business-growth'),		
		'desc'	=> __('Check To hide site title and description', 'business-growth'),
		'id'	=> 'hide_titledesc',
		'type'	=> 'checkbox',
		'std'	=> '');		
		
	$options[] = array(
		'name' => __('Responsive View Menu word changeable', 'business-growth'),
		'desc' => __('Change menu word on responsive view', 'business-growth'),
		'id' => 'menuwordchange',
		'std' => 'Menu',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Social Icon Style', 'business-growth'),
		'desc' => __('select footer icon style circle or square','business-growth'),
		'id' => 'iconstyle',
		'std' => '50',
		'type' => 'select',
		'options' => array('50'=>'Footer Social icon Style Circle', '0'=>'Footer Social icon Style Square'));	
		
	$options[] = array(
		'name' => __('Blog Single Layout', 'business-growth'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'business-growth'),
		'id' => 'singlelayout',
		'type' => 'select',
		'std' => 'singleright',
		'options' => array('singleright'=>'Blog Single Right Sidebar', 'singleleft'=>'Blog Single Left Sidebar', 'sitefull'=>'Blog Single Full Width', 'nosidebar'=>'Blog Single No Sidebar') );	
		
	$options[] = array(
		'name' => __('Woocommerce Page Layout', 'business-growth'),
		'desc' => __('Select layout. eg:right-sidebar, left-sidebar, full-width', 'business-growth'),
		'id' => 'woocommercelayout',
		'type' => 'select',
		'std' => 'woocommercesitefull',
		'options' => array('woocommerceright'=>'Woocommerce Right Sidebar', 'woocommerceleft'=>'Woocommerce Left Sidebar', 'woocommercesitefull'=>'Woocommerce Full Width') );		
		

	$options[] = array(
		'name' => __('Custom CSS', 'business-growth'),
		'desc' => __('Some Custom Styling for your site. Place any css codes here instead of the style.css file.', 'business-growth'),
		'id' => 'style2',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Sticky Header', 'business-growth'),
		'desc' => __('Check this to disable sticky header on scroll', 'business-growth'),
		'id' => 'headstick',
		'std' => '',
		'type' => 'checkbox');
		
	$options[] = array(
		'name' => __('Disable Animation', 'business-growth'),
		'desc' => __('Check this to disable animation on scroll', 'business-growth'),
		'id' => 'scrollanimation',
		'std' => '',
		'type' => 'checkbox');	
		
	// font family start 
		
	$options[] = array(
		'name' => __('Font Faces', 'business-growth'),
		'desc' => __('Select font for the body text', 'business-growth'),
		'id' => 'bodyfontface',
		'type' => 'select',
		'std' => 'PT Sans',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the textual logo', 'business-growth'),
		'id' => 'logofontface',
		'type' => 'select',
		'std' => 'Raleway',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the navigation text', 'business-growth'),
		'id' => 'navfontface',
		'type' => 'select',
		'std' => 'Raleway',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for heading text. eg: H1, H2, H3, H4, H5, H6', 'business-growth'),
		'id' => 'headfontface',
		'type' => 'select',
		'std' => 'Raleway',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font family for header top bar', 'business-growth'),
		'id' => 'hdrtopfontface',
		'type' => 'select',
		'std' => 'PT Sans',
		'options' => $font_types );	
		
	// font sizes start	
	$options[] = array(
		'name' => __('Font Sizes', 'business-growth'),
		'desc' => __('Select font size for body text', 'business-growth'),
		'id' => 'bodyfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for textual logo', 'business-growth'),
		'id' => 'logofontsize',
		'type' => 'select',
		'std' => '36px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for navigation', 'business-growth'),
		'id' => 'navfontsize',
		'type' => 'select',
		'std' => '15px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for section title', 'business-growth'),
		'id' => 'sectitlesize',
		'type' => 'select',
		'std' => '30px',
		'options' => $font_sizes );
	
		
	$options[] = array(
		'desc' => __('Select font size for footer title', 'business-growth'),
		'id' => 'ftfontsize',
		'type' => 'select',
		'std' => '18px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for header top bar', 'business-growth'),
		'id' => 'hdrtopfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );	

	// font colors start
	$options[] = array(
		'name' => __('Font Colors', 'business-growth'),
		'desc' => __('Select font color for the body text', 'business-growth'),
		'id' => 'bodyfontcolor',
		'std' => '#364558',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for textual logo', 'business-growth'),
		'id' => 'logofontcolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for section title', 'business-growth'),
		'id' => 'sectitlecolor',
		'std' => '#333333',
		'type' => 'color');			
	

	$options[] = array(
		'desc' => __('Select font color for navigation', 'business-growth'),
		'id' => 'navfontcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for navigation hover', 'business-growth'),
		'id' => 'navhovercolor',
		'std' => '#0294cf',
		'type' => 'color');
	
		
	$options[] = array(
		'desc' => __('Select font color for widget title', 'business-growth'),
		'id' => 'wdgttitleccolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer title', 'business-growth'),
		'id' => 'foottitlecolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer', 'business-growth'),
		'id' => 'footdesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer menu ', 'business-growth'),
		'id' => 'footermenucolor',
		'std' => '#ffffff',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select hover/active font color for footer menu ', 'business-growth'),
		'id' => 'footermenucurrent',
		'std' => '#0294cf',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for footer left text (copyright)', 'business-growth'),
		'id' => 'copycolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer right text (design by)', 'business-growth'),
		'id' => 'designcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags', 'business-growth'),
		'id' => 'linkcolor',
		'std' => '#0294cf',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags on hover', 'business-growth'),
		'id' => 'linkhovercolor',
		'std' => '#0294cf',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for sidebar li a', 'business-growth'),
		'id' => 'sidebarfontcolor',
		'std' => '#3b3b3b',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for sidebar li a', 'business-growth'),
		'id' => 'sidebarfonthvcolor',
		'std' => '#0294cf',
		'type' => 'color');			
			
	$options[] = array(
		'desc' => __('Select font color for Testimonials title', 'business-growth'),
		'id' => 'tmn_titlefontcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer links', 'business-growth'),
		'id' => 'copylinks',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer links', 'business-growth'),
		'id' => 'copylinkshover',
		'std' => '#0294cf',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font color for social icons', 'business-growth'),
		'id' => 'socialfontcolor',
		'std' => '#c9c8c8',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font hover color for social icons', 'business-growth'),
		'id' => 'socialfonthvcolor',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select border color for social icons', 'business-growth'),
		'id' => 'socialborder',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select border hover color for social icons', 'business-growth'),
		'id' => 'socialborderhv',
		'std' => '#0294cf',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select title color for footer posts', 'business-growth'),
		'id' => 'footerpoststitle',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select title hover color for footer posts', 'business-growth'),
		'id' => 'footerpoststitlehv',
		'std' => '#0294cf',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for our team title', 'business-growth'),
		'id' => 'teamtitlecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for our team title', 'business-growth'),
		'id' => 'teamtitlehovercolor',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select color for our team social icon', 'business-growth'),
		'id' => 'teamsicolor',
		'std' => '#555555',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select hover color for our team social icon', 'business-growth'),
		'id' => 'teamsicolorhv',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for header top bar', 'business-growth'),
		'id' => 'hdrtopfontcolor',
		'std' => '#413930',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select phone icon color for header top', 'business-growth'),
		'id' => 'phoneiconcolor',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for three column services icon', 'business-growth'),
		'id' => 'srvciconfc',
		'std' => '#333333',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for three column services icon', 'business-growth'),
		'id' => 'srvciconfchv',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select read more link color for three column services box', 'business-growth'),
		'id' => 'srvclinkcolor',
		'std' => '#78797c',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select link hover color for three column services box', 'business-growth'),
		'id' => 'srvclinkcolorhv',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select title hover color for three column services box', 'business-growth'),
		'id' => 'titlecolorhv',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for our team paragraph', 'business-growth'),
		'id' => 'teamparacolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for our theme featured title', 'business-growth'),
		'id' => 'themefeaturdtitle',
		'std' => '#333333',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for team member flip box', 'business-growth'),
		'id' => 'teamflipbxfontcolor',
		'std' => '#ffffff',
		'type' => 'color');																		
	
	// Background start		
	$options[] = array(	
		'name' => __('Background Colors', 'business-growth'),	
		'desc' => __('Select background color for header', 'business-growth'),
		'id' => 'headerbgcolor',
		'std' => '#000000',
		'type' => 'color');
		
	$options[] = array(		
		'desc' => __('Select opacity color for header background', 'business-growth'),
		'id' => 'headerbgopacity',
		'std' => '0.8',
		'type' => 'select',
		'options'	=> array('1'=>1, '0.9'=>0.9,'0.8'=>0.8,'0.7'=>0.7,'0.6'=>0.6,'0.5'=>0.5,'0.4'=>0.4,'0.3'=>0.3,'0.2'=>0.2,));				
	
		
	$options[] = array(
		'desc' => __('Select background color for footer', 'business-growth'),
		'id' => 'footerbgcolor',
		'std' => '#2d353c',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for copyright section', 'business-growth'),
		'id' => 'copybgcolor',
		'std' => '#24292f',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for gallery hover', 'business-growth'),
		'id' => 'galhvcolor',
		'std' => '#0294cf',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for sidebar widget', 'business-growth'),
		'id' => 'sidebarbgcolor',
		'std' => '#f9f9f9',
		'type' => 'color');	
		
	$options[] = array(	
		'desc' => __('Select background color for header top bar', 'business-growth'),
		'id' => 'hdrtopbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for toggle menu', 'business-growth'),
		'id' => 'togglemenu',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for top search form', 'business-growth'),
		'id' => 'searchbgcolor',
		'std' => '#0294cf',
		'type' => 'color');	
		
		
	$options[] = array(
		'desc' => __('Select background color for testimonials pagination', 'business-growth'),
		'id' => 'tmnpagerbg',
		'std' => '#464d51',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover color for testimonials pagination', 'business-growth'),
		'id' => 'tmnpagerbghv',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for sidebat widget title', 'business-growth'),
		'id' => 'widgettitlebgcolor',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for team member flip box', 'business-growth'),
		'id' => 'teamflipbxbgcolor',
		'std' => '#0294cf',
		'type' => 'color');		
		
	// Border colors	
	$options[] = array(	
		'name' => __('Border Colors', 'business-growth'),				
		'desc' => __('Select border color for header top', 'business-growth'),
		'id' => 'headerborder',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for services circle image', 'business-growth'),
		'id' => 'circleimgborder',
		'std' => '#0294cf',
		'type' => 'color');				
		
	$options[] = array(			
		'desc' => __('Select border color for iframe', 'business-growth'),
		'id' => 'iframeborder',
		'std' => '#e5e5e4',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar li a', 'business-growth'),
		'id' => 'sidebarliaborder',
		'std' => '#d0cfcf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for read more button', 'business-growth'),
		'id' => 'readmorebutton',
		'std' => '#454545',
		'type' => 'color');	
	
	$options[] = array(			
		'desc' => __('Select border hover color for read more button', 'business-growth'),
		'id' => 'readmorebuttonhv',
		'std' => '#0294cf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border bottom color for section', 'business-growth'),
		'id' => 'secborderbottom',
		'std' => '#eaeaea',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for footer title', 'business-growth'),
		'id' => 'foottitleborder',
		'std' => '#363e44',
		'type' => 'color');
		
	$options[] = array(			
		'desc' => __('Select border color for read more button', 'business-growth'),
		'id' => 'ridmorbtnborder',
		'std' => '#A8B1B8',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for section title', 'business-growth'),
		'id' => 'secttlborder',
		'std' => '#E1E1E1',
		'type' => 'color');
		
	$options[] = array(			
		'desc' => __('Select border color for section title bullet', 'business-growth'),
		'id' => 'secttlbul',
		'std' => '#cccccc',
		'type' => 'color');			
		
	$options[] = array(			
		'desc' => __('Select background color for section title', 'business-growth'),
		'id' => 'secttlbg',
		'std' => '#FCFCFC',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for filter gallery tab', 'business-growth'),
		'id' => 'gallerytabbdr',
		'std' => '#CCCCCC',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for footer recent post images', 'business-growth'),
		'id' => 'footerimageborder',
		'std' => '#ffffff',
		'type' => 'color');				
		
		
	// Default Buttons		
	$options[] = array(
		'name' => __('Button Colors', 'business-growth'),		
		'desc' => __('Select background color for button', 'business-growth'),
		'id' => 'btnbgcolor',
		'std' => '#0294cf',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select hover background color for button', 'business-growth'),
		'id' => 'btnbghvcolor',
		'std' => '#0294CF',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select font color button', 'business-growth'),
		'id' => 'btntxtcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color button on hover', 'business-growth'),
		'id' => 'btntxthvcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select background color for team member read more button ', 'business-growth'),
		'id' => 'teambtnbgcolor',
		'std' => '#555555',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select hover background color for team member read more button', 'business-growth'),
		'id' => 'teambtnbgcolorhv',
		'std' => '#ffffff',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select font color team member read more button', 'business-growth'),
		'id' => 'teambtnfontcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color team member read more button', 'business-growth'),
		'id' => 'teambtnfontcolorhv',
		'std' => '#555555',
		'type' => 'color');		
		
		
	// Slider Caption colors	
	$options[] = array(	
		'name' => __('Slider Caption Colors', 'business-growth'),			
		'desc' => __('Select font color for slider title', 'business-growth'),
		'id' => 'slidetitlecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for slider description', 'business-growth'),
		'id' => 'slidedesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for slider button', 'business-growth'),
		'id' => 'slidebtncolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font hover color for slider button', 'business-growth'),
		'id' => 'slidebtncolorhv',
		'std' => '#ffffff',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font size for slider title', 'business-growth'),
		'id' => 'slidetitlefontsize',
		'type' => 'select',
		'std' => '30px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for slider description', 'business-growth'),
		'id' => 'slidedescfontsize',
		'type' => 'select',
		'std' => '16px',
		'options' => $font_sizes );
		
		
	// Slider controls colors		
	$options[] = array(
		'name' => __('Slider controls Colors', 'business-growth'),
		'desc' => __('Select background color for slider pager', 'business-growth'),
		'id' => 'sldpagebg',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for slider pager active', 'business-growth'),
		'id' => 'sldpagehvbg',
		'std' => '#0294cf',
		'type' => 'color');	
		
	// Read More Text
	$options[] = array(
		'name' => __('Read More Text Manageable', 'business-growth'),
		'desc' => __('changes read more button text for frontpage recent posts', 'business-growth'),
		'id' => 'recentpostreadmoretext',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(			
		'desc' => __('Change your read more button text for blog templates', 'business-growth'),
		'id' => 'blogreadmoretext',
		'std' => 'Read More',
		'type' => 'text');
		
	$options[] = array(			
		'desc' => __('Change your read more button text for team member', 'business-growth'),
		'id' => 'teamreadmoretext',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Custom Excerpt Length', 'business-growth'),	
		'desc' => __('Select excerpt length for home page recent posts', 'business-growth'),
		'id' => 'hmrecentpostslength',
		'std' => '30',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Select excerpt length for Client Testimonilas', 'business-growth'),
		'id' => 'testimonialwordlength',
		'std' => '60',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Select excerpt length for footer recent posts', 'business-growth'),
		'id' => 'footerrplength',
		'std' => '10',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Select excerpt length for blog posts', 'business-growth'),
		'id' => 'blogexcerptlength',
		'std' => '70',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Select excerpt length for team member', 'business-growth'),
		'id' => 'teamexcerptlength',
		'std' => '22',
		'type' => 'text');							

	//Layout Settings
	$options[] = array(
		'name' => __('Sections', 'business-growth'),
		'type' => 'heading');
		
		
	$options[] = array(
		'name' => __('Top Four Services Columns Below the Slider','business-growth'),
		'desc'	=> __('First Services box for frontpage section','business-growth'),
		'id' 	=> 'box1',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image  for first box.', 'business-growth'),
		'id' => 'boximg1',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Second Services box for frontpage section','business-growth'),
		'id' 	=> 'box2',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image  for second box.', 'business-growth'),
		'id' => 'boximg2',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Third Services box for frontpage section','business-growth'),
		'id' 	=> 'box3',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image  for third box.', 'business-growth'),
		'id' => 'boximg3',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Fourth Services box for frontpage section','business-growth'),
		'id' 	=> 'box4',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image  for fourth box.', 'business-growth'),
		'id' => 'boximg4',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(	
		'desc'	=> __('Fifth Services box for frontpage section','business-growth'),
		'id' 	=> 'box5',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image  for fifth box.', 'business-growth'),
		'id' => 'boximg5',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('change custom excerpt length for page boxes', 'business-growth'),
		'id' => 'pageboxlength',
		'std' => '25',
		'type' => 'text');			
	
	$options[] = array(
		'desc' => __('Read More Button Text for Pages boxes', 'business-growth'),
		'id' => 'pagemorebutton',
		'std' => 'Read More',
		'type' => 'text');
		
	
	$options[] = array(			
			'desc'	=> __('Check to hide four column section below the slider', 'business-growth'),
			'id'	=> 'hidefourbxsec',
			'type'	=> 'checkbox',
			'std'	=> '');	

	$options[] = array(
		'name' => __('Number of Sections', 'business-growth'),
		'desc' => __('Select number of sections', 'business-growth'),
		'id' => 'numsection',
		'type' => 'select',
		'std' => '7',
		'options' => array_combine(range(1,30), range(1,30)) );

	$numsecs = of_get_option( 'numsection', 7 );

	for( $n=1; $n<=$numsecs; $n++){
		$options[] = array(
			'desc' => __("<h3>Section ".$n."</h3>", 'business-growth'),
			'class' => 'toggle_title',
			'type' => 'info');	
	
		$options[] = array(
			'name' => __('Section Title', 'business-growth'),
			'id' => 'sectiontitle'.$n,
			'std' => ( ( isset($section_text[$n]['section_title']) ) ? $section_text[$n]['section_title'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section ID', 'business-growth'),
			'desc'	=> __('Enter your section ID here. SECTION ID MUST BE IN SMALL LETTERS ONLY AND DO NOT ADD SPACE OR SYMBOL.'),
			'id' => 'menutitle'.$n,
			'std' => ( ( isset($section_text[$n]['menutitle']) ) ? $section_text[$n]['menutitle'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section Background Color', 'business-growth'),
			'desc' => __('Select background color for section', 'business-growth'),
			'id' => 'sectionbgcolor'.$n,
			'std' => ( ( isset($section_text[$n]['bgcolor']) ) ? $section_text[$n]['bgcolor'] : '' ),
			'type' => 'color');
			
		$options[] = array(
			'name' => __('Background Image', 'business-growth'),
			'id' => 'sectionbgimage'.$n,
			'class' => '',
			'std' => ( ( isset($section_text[$n]['bgimage']) ) ? $section_text[$n]['bgimage'] : '' ),
			'type' => 'upload');

		$options[] = array(
			'name' => __('Section CSS Class', 'business-growth'),
			'desc' => __('Set class for this section.', 'business-growth'),
			'id' => 'sectionclass'.$n,
			'std' => ( ( isset($section_text[$n]['class']) ) ? $section_text[$n]['class'] : '' ),
			'type' => 'text');
			
		$options[] = array(
			'name'	=> __('Hide Section', 'business-growth'),
			'desc'	=> __('Check to hide this section', 'business-growth'),
			'id'	=> 'hidesec'.$n,
			'type'	=> 'checkbox',
			'std'	=> '');

		$options[] = array(
			'name' => __('Section Content', 'business-growth'),
			'id' => 'sectioncontent'.$n,
			'std' => ( ( isset($section_text[$n]['content']) ) ? $section_text[$n]['content'] : '' ),
			'type' => 'editor');
	}


	//SLIDER SETTINGS
	$options[] = array(
		'name' => __('Homepage Slider', 'business-growth'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Innerpage Banner', 'business-growth'),
		'desc' => __('Upload header innerpage banner for site', 'business-growth'),
		'id' => 'innerbanner',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/default-banner.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'name' => __('Custom Slider Shortcode Area For Home Page', 'business-growth'),
		'desc' => __('Enter here your slider shortcode without php tag', 'business-growth'),
		'id' => 'customslider',
		'std' => '',
		'type' => 'textarea');			
		
	$options[] = array(
		'name' => __('Slider Effects and Timing', 'business-growth'),
		'desc' => __('Select slider effect.','business-growth'),
		'id' => 'slideefect',
		'std' => 'fade',
		'type' => 'select',
		'options' => array('random'=>'Random', 'fade'=>'Fade', 'fold'=>'Fold', 'sliceDown'=>'Slide Down', 'sliceDownLeft'=>'Slide Down Left', 'sliceUp'=>'Slice Up', 'sliceUpLeft'=>'Slice Up Left', 'sliceUpDown'=>'Slice Up Down', 'sliceUpDownLeft'=>'Slice Up Down Left', 'slideInRight'=>'SlideIn Right', 'slideInLeft'=>'SlideIn Left', 'boxRandom'=>'Box Random', 'boxRain'=>'Box Rain', 'boxRainReverse'=>'Box Rain Reverse', 'boxRainGrow'=>'Box Rain Grow', 'boxRainGrowReverse'=>'Box Rain Grow Reverse' ));
		
	$options[] = array(
		'desc' => __('Animation speed should be multiple of 100.', 'business-growth'),
		'id' => 'slideanim',
		'std' => 500,
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add slide pause time.', 'business-growth'),
		'id' => 'slidepause',
		'std' => 4000,
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slide Controllers', 'business-growth'),
		'desc' => __('Hide/Show Next, Prev arrows of slider.','business-growth'),
		'id' => 'slidenav',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Hide/Show pager of slider.','business-growth'),
		'id' => 'slidepage',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Pause Slide on Hover.','business-growth'),
		'id' => 'slidepausehover',
		'std' => 'false',
		'type' => 'select',
		'options' => array('true'=>'Yes', 'false'=>'No'));
		
	$options[] = array(
		'name' => __('Slider Image 1', 'business-growth'),
		'desc' => __('First Slide', 'business-growth'),
		'id' => 'slide1',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider1.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 1', 'business-growth'),
		'id' => 'slidetitle1',
		'std' => 'The <strong>BizGroth</strong> Wordpress themes is <br><strong>100% Responsive</strong>',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc1',
		'std' => 'A Framework Suited For Everyone without coding knowledge',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton1',
		'std' => 'Read More',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl1',
		'std' => '#',
		'type' => 'text');		
		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'business-growth'),
		'desc' => __('Second Slide', 'business-growth'),
		'class' => '',
		'id' => 'slide2',
		'std' => get_template_directory_uri()."/images/slides/slider2.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 2', 'business-growth'),
		'id' => 'slidetitle2',
		'std' => 'The <strong>BizGroth</strong> Multipurpose Wordpress themes <br> is <strong>Cross-Browser Compatible</strong>',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc2',
		'std' => 'Nunc sed lorem pretium, Sed bibendum quis volutpat tortor id, adipiscing sem.',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton2',
		'std' => 'Read More',
		'type' => 'text');	
			
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl2',
		'std' => '#',
		'type' => 'text');	
	
		
	$options[] = array(
		'name' => __('Slider Image 3', 'business-growth'),
		'desc' => __('Third Slide', 'business-growth'),
		'id' => 'slide3',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider3.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 3', 'business-growth'),
		'id' => 'slidetitle3',
		'std' => 'The <strong>BizGroth</strong> Simple Wordpress  themes <br> is <strong>User Friendly</strong> ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc3',
		'std' => 'Nunc sed lorem pretium, volutpat tortor id, adipiscing sem. Sed bibendum quis augue volutpat tortor id, adipiscing sem. Sed bibendum quis augue nec nec porta ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton3',
		'std' => 'Read More',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl3',
		'std' => '#',
		'type' => 'text');	
			
	
	$options[] = array(
		'name' => __('Slider Image 4', 'business-growth'),
		'desc' => __('Fourth Slide', 'business-growth'),
		'id' => 'slide4',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 4', 'business-growth'),
		'id' => 'slidetitle4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton4',
		'std' => '',
		'type' => 'text');	
				
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl4',
		'std' => '',
		'type' => 'text');				
	
	$options[] = array(
		'name' => __('Slider Image 5', 'business-growth'),
		'desc' => __('Fifth Slide', 'business-growth'),
		'id' => 'slide5',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 5', 'business-growth'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton5',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl5',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 6', 'business-growth'),
		'desc' => __('Sixth Slide', 'business-growth'),
		'id' => 'slide6',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
		
	$options[] = array(
		'desc' => __('Title 6', 'business-growth'),
		'id' => 'slidetitle6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton6',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl6',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 7', 'business-growth'),
		'desc' => __('Seventh Slide', 'business-growth'),
		'id' => 'slide7',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 7', 'business-growth'),
		'id' => 'slidetitle7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton7',
		'std' => '',
		'type' => 'text');				
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl7',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 8', 'business-growth'),
		'desc' => __('Eighth Slide', 'business-growth'),
		'id' => 'slide8',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 8', 'business-growth'),
		'id' => 'slidetitle8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton8',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl8',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 9', 'business-growth'),
		'desc' => __('Ninth Slide', 'business-growth'),
		'id' => 'slide9',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 9', 'business-growth'),
		'id' => 'slidetitle9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton9',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl9',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 10', 'business-growth'),
		'desc' => __('Tenth Slide', 'business-growth'),
		'id' => 'slide10',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 10', 'business-growth'),
		'id' => 'slidetitle10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'business-growth'),
		'id' => 'slidebutton10',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'business-growth'),
		'id' => 'slidedesc10',
		'std' => '',
		'type' => 'textarea');			
	
	$options[] = array(
		'desc' => __('Slide Url', 'business-growth'),
		'id' => 'slideurl10',
		'std' => '',
		'type' => 'text');

	//Footer SETTINGS
	$options[] = array(
		'name' => __('Footer', 'business-growth'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Footer Layout', 'business-growth'),
		'desc' => __('footer Select layout. eg:Boxed, 1, 2, 3 and 4', 'business-growth'),
		'id' => 'footerlayout',
		'type' => 'select',
		'std' => 'fourcolumn',
		'options' => array('onecolumn'=>'Footer 1 column', 
		'twocolumn'=>'Footer 2 column', 'threecolumn'=>'Footer 3 column', 'fourcolumn'=>'Footer 4 column', ) );		
				
	$options[] = array(
		'name' => __('Footer About Us', 'business-growth'),
		'desc' => __('about us text title for footer', 'business-growth'),
		'id' => 'aboutustitle',
		'std' => 'About Us',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('About Description', 'business-growth'),
		'desc' => __('about text description for footer', 'business-growth'),
		'id' => 'aboutdescription',
		'std' => '<p>Nam aliquet aliquam ipsum eget volutpat. Duis nec porta purus. Integer adipiscing augue sit amet libero vulputate, et fermentum nibh rutrum. In bibendum nisi sed consequat hendrerit. Aliquam.</p>
<p>Quisque elementum, dolor nec tempus eleifend, nibh mauris aliquet ante, eu tempus sapien nisi non nunc. Nulla facilisi. </p> ',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Our Menu', 'business-growth'),
		'desc' => __('Footer menu title.', 'business-growth'),
		'id' => 'usefullinktitle',
		'std' => 'Our Menu',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('add social icon name and link in the shortcodes.', 'business-growth'),
		'id' => 'footersocialicons',
		'std' => '[social_area]
    [social icon="facebook" link="#"]
    [social icon="twitter" link="#"]
    [social icon="linkedin" link="#"]
    [social icon="pinterest" link="#"]
    [social icon="google-plus" link="#"]	
[/social_area]',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __(' Recent Posts Title', 'business-growth'),
		'desc' => __('recent posts title for footer.', 'business-growth'),
		'id' => 'frptitle',
		'std' => 'Recent Posts',
		'type' => 'text');	
		
		
	$options[] = array(
		'name' => __('Footer Address Title', 'business-growth'),
		'desc' => __('Add contact title here', 'business-growth'),
		'id' => 'contacttitle',
		'std' => 'Contact Info',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Add company address1 here.', 'business-growth'),
		'id' => 'address',
		'std' => '100 King St, Newyork PTI 109, United State.',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Add phone number here.', 'business-growth'),
		'id' => 'phone',
		'std' => '+1 800 234 5678',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add email address here.', 'business-growth'),
		'id' => 'email',
		'std' => 'info@sitename.com',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add company url here with http://.', 'business-growth'),
		'id' => 'weblink',
		'std' => 'http://dummylink.com',
		'type' => 'text');
		
		$options[] = array(
		'name' => __('Google Map', 'business-growth'),
		'desc' => __('Use iframe code url here. DO NOT APPLY IFRAME TAG', 'business-growth'),
		'id' => 'googlemap',
		'std' => 'https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d336003.6066860609!2d2.349634820486094!3d48.8576730786213!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x47e66e1f06e2b70f%3A0x040b82c3688c9460!2sParis%2C+France!5e0!3m2!1sen!2sin!4v1433482358672',
		'type' => 'textarea');
			
	
		
	$options[] = array(
		'name' => __('Footer Copyright', 'business-growth'),
		'desc' => __('Copyright Text for your site.', 'business-growth'),
		'id' => 'copytext',
		'std' => '&copy; 2020 <a href="#">Business Growth. </a> All Rights Reserved',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Footre Text Link', 'business-growth'),
		'id' => 'ftlink',
		'std' => 'Design by <a href="'.esc_url('http://www.gracethemes.com/').'" target="_blank">Grace Themes</a>',
		'type' => 'textarea',);
		
	$options[] = array(
		'desc' => __('Footer Back to Top Button', 'business-growth'),
		'id' => 'backtotop',
		'std' => '[back-to-top]',
		'type' => 'textarea',);	

	//Short codes
	$options[] = array(
		'name' => __('Short Codes', 'business-growth'),
		'type' => 'heading');	
		
	
	$options[] = array(
		'name' => __('Photo Gallery', 'business-growth'),
		'desc' => __('[photogallery filter="true" show="8"]', 'business-growth'),
		'type' => 'info');			
			
		
	$options[] = array(
		'name' => __('Testimonials', 'business-growth'),
		'desc' => __('[testimonials]', 'business-growth'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Testimonials Listing', 'business-growth'),
		'desc' => __('[testimonials-listing show="10"]', 'business-growth'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Contact Form', 'business-growth'),
		'desc' => __('[contactform to_email="test@example.com" title="Contact Form"] 
', 'business-growth'),
		'type' => 'info');		
		
	$options[] = array(
		'name' => __('Footer posts', 'business-growth'),
		'desc' => __('[footer-posts show="2"]', 'business-growth'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Team Member', 'business-growth'),
		'desc' => __('[ourteam show="4"]', 'business-growth'),
		'type' => 'info');					
	
				
	$options[] = array(
		'name' => __('Search Form', 'business-growth'),
		'desc' => __('[searchform] 
', 'business-growth'),
		'type' => 'info');
			
		
	$options[] = array(
		'name' => __('Headings', 'business-growth'),
		'desc' => __('[heading underline="yes" align="left"]Our Team[/heading]', 'business-growth'),
		'type' => 'info');					

	$options[] = array(
		'name' => __('View More Button', 'business-growth'),
		'desc' => __('[readmore-link align="left" button="Read More" links="#"]', 'business-growth'),
		'type' => 'info');	

		
	$options[] = array(
		'name' => __('Social Icons ( Note: More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/)', 'business-growth'),
		'desc' => __('[social_area]
    [social icon="facebook" link="#"]
    [social icon="twitter" link="#"]
    [social icon="linkedin" link="#"]
    [social icon="pinterest" link="#"]
    [social icon="google-plus" link="#"]
	[social icon="youtube" link="#"]
	[social icon="wordpress" link="#"]
	[social icon="flickr" link="#"]
	[social icon="skype" link="#"]
[/social_area]', 'business-growth'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Our Skills', 'business-growth'),
		'desc' => __('[skill title="Php Coding" percent="95" bgcolor="#65676a"][skill title="Web Design" percent="85" bgcolor="#65676a"][skill title="Web Development" percent="90" bgcolor="#65676a"][skill title="SEO" percent="80" bgcolor="#65676a"]', 'business-growth'),
		'type' => 'info');		
		
		

	$options[] = array(
		'name' => __('2 Column Content', 'business-growth'),
		'desc' => __('<pre>
[column_content type="one_half"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_half_last"]
	Column 2 Content goes here...
[/column_content]
</pre>', 'business-growth'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('3 Column Content', 'business-growth'),
		'desc' => __('<pre>
[column_content type="one_third"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_third"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_third_last"]
	Column 3 Content goes here...
[/column_content]
</pre>', 'business-growth'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('4 Column Content', 'business-growth'),
		'desc' => __('<pre>
[column_content type="one_fourth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fourth_last"]
	Column 4 Content goes here...
[/column_content]
</pre>', 'business-growth'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('5 Column Content', 'business-growth'),
		'desc' => __('<pre>
[column_content type="one_fifth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 4 Content goes here...
[/column_content]

[column_content type="one_fifth_last"]
	Column 5 Content goes here...
[/column_content]
</pre>', 'business-growth'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Clear', 'business-growth'),
		'desc' => __('<pre>
[clear]
</pre>', 'business-growth'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('HR / Horizontal separation line', 'business-growth'),
		'desc' => __('<pre>
[hr] or &lt;hr&gt;
</pre>', 'business-growth'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Separator / blank space', 'business-growth'),
		'desc' => __('<pre>
[separator height="20"]
</pre>', 'business-growth'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Blank space without image', 'business-growth'),
		'desc' => __('<pre>
[blankspace height="20"]
</pre>', 'business-growth'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Tabs', 'business-growth'),
		'desc' => __('<pre>
[tabs]
	[tab title="TAB TITLE 1"]
		TAB CONTENT 1
	[/tab]
	[tab title="TAB TITLE 2"]
		TAB CONTENT 2
	[/tab]
	[tab title="TAB TITLE 3"]
		TAB CONTENT 3
	[/tab]
[/tabs]
</pre>', 'business-growth'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Toggle Content', 'business-growth'),
		'desc' => __('<pre>
[toggle_content title="Toggle Title 1"]
	Toggle content 1...
[/toggle_content]
[toggle_content title="Toggle Title 2"]
	Toggle content 2...
[/toggle_content]
[toggle_content title="Toggle Title 3"]
	Toggle content 3...
[/toggle_content]
</pre>', 'business-growth'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Accordion Content', 'business-growth'),
		'desc' => __('<pre>
[accordion]
	[accordion_content title="ACCORDION TITLE 1"]
		ACCORDION CONTENT 1
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 2"]
		ACCORDION CONTENT 2
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 3"]
		ACCORDION CONTENT 3
	[/accordion_content]
[/accordion]
</pre>', 'business-growth'),
		'type' => 'info');

	$options[] = array(
		'name' => __('List Styles', 'business-growth'),
		'desc' => __('<pre>
[unordered_list style="list-1"]&lt;li&gt;List style 1&lt;/li&gt;[/unordered_list]
</pre>
<br />You can use above shortcode OR simply add class to ul. You can choose from list-1 to list-10 styles.<br />
<pre>
&lt;ul class="list-1"&gt;&lt;li&gt;List style 1&lt;/li&gt;&lt;/ul&gt;
</pre>
', 'business-growth'),
		'type' => 'info');
		
	
	$options[] = array(
		'name' => __('Back to Top', 'business-growth'),
		'desc' => __('[back-to-top]', 'business-growth'),
		'type' => 'info');

	return $options;
}